{ pkgs, ... }:

let
  actualPkgs = pkgs.unstablePkgs;

  nodePkgs = with actualPkgs.nodePackages; [
    vscode-langservers-extracted
    typescript
    svelte-language-server
    yaml-language-server
    typescript-language-server
    bash-language-server
    pyright
  ];
in
{
  home = {
    packages = with actualPkgs; [
      black
      helix
      clang-tools
      rust-analyzer
      nil
      texlab
      nixpkgs-fmt
      ruff
      ruff-lsp
      mypy
      shellcheck
      shfmt
      gopls
      golangci-lint
      golangci-lint-langserver
    ] ++ nodePkgs;

    sessionVariables = {
      EDITOR = "hx";
      VISUAL = "hx";
    };

    file = {
      ".config/helix/config.toml".text = ''
        theme = "monokai_pro_spectrum"

        [editor]
        cursorline = true
        true-color = true
        gutters = ["diff", "diagnostics", "line-numbers", "spacer"]
      
        [editor.cursor-shape]
        insert = "bar"
        normal = "block"
        select = "underline"

        [editor.lsp]
        display-messages = true

        [editor.indent-guides]
        render = true

        [editor.statusline]
        left = ["mode", "spinner"]
        center = ["file-name"]
      '';

      ".config/helix/languages.toml".text = ''
        [[language]]
        name = "nix"
        formatter = { command = "nixpkgs-fmt" }

        [[language]]
        name = "go"
        language-servers = ["gopls", "golangci-lint-langserver"]
 
        [language-server.golangci-lint-langserver]
        command = "golangci-lint-langserver"
 
        [language-server.golangci-lint-langserver.config]
        command = ["golangci-lint", "run","--enable-all", "-D", "godox", "-D", "godot", "--out-format", "json", "--issues-exit-code=1"]

      '';
    };
  };
}
